@@ -66,10 +66,27 @@ theme_clean = function(base_size = 12)
   )
 }
 
-# make the output of cut2 a bit easier to read
-# see http://stackoverflow.com/questions/22416612/how-can-i-get-cut2-to-use-commas/
+#' Make the output of cut2 a bit easier to read
+#' 
+#' Adds commas to numbers, removes unnecessary whitespace and allows an arbitrary separator.
+#' 
+#' @param x A factor with levels created via Hmisc::cut2.
+#' @param nsep A separator which you wish to use.  Defaults to " to ".
+#' 
+#' @export
+#' @examples
+#' data(choroplethr)
+#'
+#' x = Hmisc::cut2(df_pop_state$value, g=3)
+#' levels(x)
+#' # [1] "[ 562803, 2851183)" "[2851183, 6353226)" "[6353226,37325068]"
+#' levels(x) = sapply(levels(x), format_levels)
+#' levels(x)
+#' # [1] "[562,803 to 2,851,183)"    "[2,851,183 to 6,353,226)"  "[6,353,226 to 37,325,068]"
+#'
+#' @seealso \url{http://stackoverflow.com/questions/22416612/how-can-i-get-cut2-to-use-commas/}, which this implementation is based on.
 #' @importFrom stringr str_extract_all
-format_levels = function(x,nsep=" to ") 
+format_levels = function(x, nsep=" to ") 
 {
   n = str_extract_all(x, "[-+]?[0-9]*\\.?[0-9]+")[[1]]  # extract numbers
   v = format(as.numeric(n), big.mark=",", trim=TRUE) # change format
@@ -108,3 +125,17 @@ discretize_values = function(values, num_buckets)
   levels(ret) = sapply(levels(ret), format_levels)
   ret
 }
+
+discretize_df = function(df, num_buckets)
+{
+  stopifnot(is.data.frame(df))
+  stopifnot("value" %in% colnames(df))
+  stopifnot(is.numeric(num_buckets) && num_buckets > 0 && num_buckets < 10)
+  
+  if (is.numeric(df$value) && num_buckets > 1) {
+    df$value = discretize_values(df$value, num_buckets)
+  }
+  
+  df
+}
+
