@@ -19,3 +19,11 @@ test_that("zip level choropleths return ggplots at discrete and continuous lods"
   expect_is(choroplethr(df, lod="zip", num_buckets=1), "ggplot")
   expect_is(choroplethr(df, lod="zip", num_buckets=9), "ggplot")
 })
+
+test_that("county level choropleths handle leading zeros for states", {
+  # los angeles and san francisco
+  df = data.frame(region=c("06037", "06075"), value=c(200,100))
+  expect_is(choroplethr(df, lod="county", num_buckets=1), "ggplot")
+  expect_is(choroplethr(df, lod="county", num_buckets=2), "ggplot")
+})
+
